==> agrosyst-cli-1.4.5-sources.jar: fr/inra/agrosyst/services/pz0import/domain/model/CroppingPlanEntryImportModel.java <==
package fr.inra.agrosyst.services.pz0import.domain.model;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: CroppingPlanEntryImportModel.java 4748 2015-02-03 09:28:19Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.5/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/domain/model/CroppingPlanEntryImportModel.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.services.pz0import.AbstractAgrosystModelExtended;
import fr.inra.agrosyst.services.pz0import.domain.dto.CroppingPlanEntryImportDto;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Created by davidcosse on 05/12/14.
 */
public class CroppingPlanEntryImportModel extends AbstractAgrosystModelExtended<CroppingPlanEntryImportDto> {

    private static final Log log = LogFactory.getLog(CroppingPlanEntryImportModel.class);

    public CroppingPlanEntryImportModel() {
        super(';');

        newMandatoryColumn("topiaid", "id");
        newIgnoredColumn("topiaversion");
        newMandatoryColumn("code", "code");
        newMandatoryColumn("domain", "domainId");
        newIgnoredColumn("topiacreatedate");
        newMandatoryColumn("name", "name");
        newMandatoryColumn("sellingprice", "sellingPrice", DOUBLE_WITH_NULL_PARSER);
        newMandatoryColumn("validated", "validated", T_F_PARSER);
        newMandatoryColumn("type", "typeImporterValue");
    }

    @Override
    public CroppingPlanEntryImportDto newEmptyInstance() {
        return new CroppingPlanEntryImportDto();
    }

}

==> agrosyst-cli-1.4.6-sources.jar: fr/inra/agrosyst/services/pz0import/domain/model/CroppingPlanEntryImportModel.java <==
package fr.inra.agrosyst.services.pz0import.domain.model;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: CroppingPlanEntryImportModel.java 4748 2015-02-03 09:28:19Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/1.4.6/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/domain/model/CroppingPlanEntryImportModel.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.services.pz0import.AbstractAgrosystModelExtended;
import fr.inra.agrosyst.services.pz0import.domain.dto.CroppingPlanEntryImportDto;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Created by davidcosse on 05/12/14.
 */
public class CroppingPlanEntryImportModel extends AbstractAgrosystModelExtended<CroppingPlanEntryImportDto> {

    private static final Log log = LogFactory.getLog(CroppingPlanEntryImportModel.class);

    public CroppingPlanEntryImportModel() {
        super(';');

        newMandatoryColumn("topiaid", "id");
        newIgnoredColumn("topiaversion");
        newMandatoryColumn("code", "code");
        newMandatoryColumn("domain", "domainId");
        newIgnoredColumn("topiacreatedate");
        newMandatoryColumn("name", "name");
        newMandatoryColumn("sellingprice", "sellingPrice", DOUBLE_WITH_NULL_PARSER);
        newMandatoryColumn("validated", "validated", T_F_PARSER);
        newMandatoryColumn("type", "typeImporterValue");
    }

    @Override
    public CroppingPlanEntryImportDto newEmptyInstance() {
        return new CroppingPlanEntryImportDto();
    }

}
